# trieres
This is a python module enabling the remote execution of accelerated functions on the [cloudFPGA platform](https://www.zurich.ibm.com/cci/cloudFPGA/).

## Workflow

* git clone --depth 1 --recursively git@github.com:cloudFPGA/trieres.git
* cd trieres  
* make env
* make genlib
* make upload
